--
-- Copyright 2006 University of Dundee. All rights reserved.
-- Use is subject to license terms supplied in LICENSE.txt
--

--
-- This file was generated by dsl/resources/ome/dsl/data.vm
--

set constraints all deferred;

--
-- #1176 : create our own nextval() functionality for more consistent
-- sequence operation in hibernate. This functionality was updated for
-- OMERO 4.2 (#2508) in order to prevent logging during triggers.
--

CREATE OR REPLACE FUNCTION ome_nextval(seq VARCHAR) RETURNS INT8 AS '
BEGIN
      RETURN ome_nextval(seq, 1);
END;' LANGUAGE plpgsql;

-- These renamings allow us to reuse the Hibernate-generated tables
-- for sequence generation. Eventually, a method might be found to
-- make Hibernate generate them for us.
CREATE SEQUENCE _lock_seq;
ALTER TABLE seq_table RENAME TO _lock_ids;
ALTER TABLE _lock_ids RENAME COLUMN sequence_name TO name;
ALTER TABLE _lock_ids DROP CONSTRAINT seq_table_pkey;
ALTER TABLE _lock_ids DROP COLUMN next_val;
ALTER TABLE _lock_ids ADD COLUMN id int PRIMARY KEY DEFAULT nextval('_lock_seq');
CREATE UNIQUE INDEX _lock_ids_name ON _lock_ids (name);

CREATE OR REPLACE FUNCTION ome_nextval(seq VARCHAR, increment int4) RETURNS INT8 AS '
DECLARE
      Lid  int4;
      nv   int8;
BEGIN
      SELECT id INTO Lid FROM _lock_ids WHERE name = seq;
      IF Lid IS NULL THEN
          SELECT INTO Lid nextval(''_lock_seq'');
          INSERT INTO _lock_ids (id, name) VALUES (Lid, seq);
      END IF;

      BEGIN
        PERFORM pg_advisory_lock(1, Lid);
      EXCEPTION
        WHEN undefined_function THEN
          RAISE DEBUG ''No function pg_advisory_lock'';
      END;
      PERFORM nextval(seq) FROM generate_series(1, increment);
      SELECT currval(seq) INTO nv;
      BEGIN
        PERFORM pg_advisory_unlock(1, Lid);
      EXCEPTION
        WHEN undefined_function THEN
          RAISE DEBUG ''No function pg_advisory_unlock'';
      END;

      RETURN nv;

END;' LANGUAGE plpgsql;

CREATE SEQUENCE seq_wellsampleannotationlink; INSERT INTO _lock_ids (name, id) SELECT 'seq_wellsampleannotationlink', nextval('_lock_seq');
CREATE SEQUENCE seq_wellannotationlink; INSERT INTO _lock_ids (name, id) SELECT 'seq_wellannotationlink', nextval('_lock_seq');
CREATE SEQUENCE seq_filtertype; INSERT INTO _lock_ids (name, id) SELECT 'seq_filtertype', nextval('_lock_seq');
CREATE SEQUENCE seq_dataset; INSERT INTO _lock_ids (name, id) SELECT 'seq_dataset', nextval('_lock_seq');
CREATE SEQUENCE seq_plate; INSERT INTO _lock_ids (name, id) SELECT 'seq_plate', nextval('_lock_seq');
CREATE SEQUENCE seq_thumbnail; INSERT INTO _lock_ids (name, id) SELECT 'seq_thumbnail', nextval('_lock_seq');
CREATE SEQUENCE seq_immersion; INSERT INTO _lock_ids (name, id) SELECT 'seq_immersion', nextval('_lock_seq');
CREATE SEQUENCE seq_channel; INSERT INTO _lock_ids (name, id) SELECT 'seq_channel', nextval('_lock_seq');
CREATE SEQUENCE seq_imageannotationlink; INSERT INTO _lock_ids (name, id) SELECT 'seq_imageannotationlink', nextval('_lock_seq');
CREATE SEQUENCE seq_link; INSERT INTO _lock_ids (name, id) SELECT 'seq_link', nextval('_lock_seq');
CREATE SEQUENCE seq_lightpathemissionfilterlink; INSERT INTO _lock_ids (name, id) SELECT 'seq_lightpathemissionfilterlink', nextval('_lock_seq');
CREATE SEQUENCE seq_arctype; INSERT INTO _lock_ids (name, id) SELECT 'seq_arctype', nextval('_lock_seq');
CREATE SEQUENCE seq_experimenttype; INSERT INTO _lock_ids (name, id) SELECT 'seq_experimenttype', nextval('_lock_seq');
CREATE SEQUENCE seq_filtersetemissionfilterlink; INSERT INTO _lock_ids (name, id) SELECT 'seq_filtersetemissionfilterlink', nextval('_lock_seq');
CREATE SEQUENCE seq_filtersetexcitationfilterlink; INSERT INTO _lock_ids (name, id) SELECT 'seq_filtersetexcitationfilterlink', nextval('_lock_seq');
CREATE SEQUENCE seq_microscope; INSERT INTO _lock_ids (name, id) SELECT 'seq_microscope', nextval('_lock_seq');
CREATE SEQUENCE seq_originalfileannotationlink; INSERT INTO _lock_ids (name, id) SELECT 'seq_originalfileannotationlink', nextval('_lock_seq');
CREATE SEQUENCE seq_wellsample; INSERT INTO _lock_ids (name, id) SELECT 'seq_wellsample', nextval('_lock_seq');
CREATE SEQUENCE seq_planeinfo; INSERT INTO _lock_ids (name, id) SELECT 'seq_planeinfo', nextval('_lock_seq');
CREATE SEQUENCE seq_lightpathexcitationfilterlink; INSERT INTO _lock_ids (name, id) SELECT 'seq_lightpathexcitationfilterlink', nextval('_lock_seq');
CREATE SEQUENCE seq_groupexperimentermap; INSERT INTO _lock_ids (name, id) SELECT 'seq_groupexperimentermap', nextval('_lock_seq');
CREATE SEQUENCE seq_planeinfoannotationlink; INSERT INTO _lock_ids (name, id) SELECT 'seq_planeinfoannotationlink', nextval('_lock_seq');
CREATE SEQUENCE seq_transmittancerange; INSERT INTO _lock_ids (name, id) SELECT 'seq_transmittancerange', nextval('_lock_seq');
CREATE SEQUENCE seq_wellreagentlink; INSERT INTO _lock_ids (name, id) SELECT 'seq_wellreagentlink', nextval('_lock_seq');
CREATE SEQUENCE seq_eventlog; INSERT INTO _lock_ids (name, id) SELECT 'seq_eventlog', nextval('_lock_seq');
CREATE SEQUENCE seq_quantumdef; INSERT INTO _lock_ids (name, id) SELECT 'seq_quantumdef', nextval('_lock_seq');
CREATE SEQUENCE seq_namespace; INSERT INTO _lock_ids (name, id) SELECT 'seq_namespace', nextval('_lock_seq');
CREATE SEQUENCE seq_image; INSERT INTO _lock_ids (name, id) SELECT 'seq_image', nextval('_lock_seq');
CREATE SEQUENCE seq_renderingmodel; INSERT INTO _lock_ids (name, id) SELECT 'seq_renderingmodel', nextval('_lock_seq');
CREATE SEQUENCE seq_microbeammanipulation; INSERT INTO _lock_ids (name, id) SELECT 'seq_microbeammanipulation', nextval('_lock_seq');
CREATE SEQUENCE seq_joboriginalfilelink; INSERT INTO _lock_ids (name, id) SELECT 'seq_joboriginalfilelink', nextval('_lock_seq');
CREATE SEQUENCE seq_experimentergroup; INSERT INTO _lock_ids (name, id) SELECT 'seq_experimentergroup', nextval('_lock_seq');
CREATE SEQUENCE seq_renderingdef; INSERT INTO _lock_ids (name, id) SELECT 'seq_renderingdef', nextval('_lock_seq');
CREATE SEQUENCE seq_datasetimagelink; INSERT INTO _lock_ids (name, id) SELECT 'seq_datasetimagelink', nextval('_lock_seq');
CREATE SEQUENCE seq_codomainmapcontext; INSERT INTO _lock_ids (name, id) SELECT 'seq_codomainmapcontext', nextval('_lock_seq');
CREATE SEQUENCE seq_eventtype; INSERT INTO _lock_ids (name, id) SELECT 'seq_eventtype', nextval('_lock_seq');
CREATE SEQUENCE seq_project; INSERT INTO _lock_ids (name, id) SELECT 'seq_project', nextval('_lock_seq');
CREATE SEQUENCE seq_microscopetype; INSERT INTO _lock_ids (name, id) SELECT 'seq_microscopetype', nextval('_lock_seq');
CREATE SEQUENCE seq_channelannotationlink; INSERT INTO _lock_ids (name, id) SELECT 'seq_channelannotationlink', nextval('_lock_seq');
CREATE SEQUENCE seq_filamenttype; INSERT INTO _lock_ids (name, id) SELECT 'seq_filamenttype', nextval('_lock_seq');
CREATE SEQUENCE seq_stagelabel; INSERT INTO _lock_ids (name, id) SELECT 'seq_stagelabel', nextval('_lock_seq');
CREATE SEQUENCE seq_photometricinterpretation; INSERT INTO _lock_ids (name, id) SELECT 'seq_photometricinterpretation', nextval('_lock_seq');
CREATE SEQUENCE seq_experimentergroupannotationlink; INSERT INTO _lock_ids (name, id) SELECT 'seq_experimentergroupannotationlink', nextval('_lock_seq');
CREATE SEQUENCE seq_pixels; INSERT INTO _lock_ids (name, id) SELECT 'seq_pixels', nextval('_lock_seq');
CREATE SEQUENCE seq_lightpath; INSERT INTO _lock_ids (name, id) SELECT 'seq_lightpath', nextval('_lock_seq');
CREATE SEQUENCE seq_roi; INSERT INTO _lock_ids (name, id) SELECT 'seq_roi', nextval('_lock_seq');
CREATE SEQUENCE seq_roiannotationlink; INSERT INTO _lock_ids (name, id) SELECT 'seq_roiannotationlink', nextval('_lock_seq');
CREATE SEQUENCE seq_externalinfo; INSERT INTO _lock_ids (name, id) SELECT 'seq_externalinfo', nextval('_lock_seq');
CREATE SEQUENCE seq_annotationannotationlink; INSERT INTO _lock_ids (name, id) SELECT 'seq_annotationannotationlink', nextval('_lock_seq');
CREATE SEQUENCE seq_objectivesettings; INSERT INTO _lock_ids (name, id) SELECT 'seq_objectivesettings', nextval('_lock_seq');
CREATE SEQUENCE seq_lasertype; INSERT INTO _lock_ids (name, id) SELECT 'seq_lasertype', nextval('_lock_seq');
CREATE SEQUENCE seq_nodeannotationlink; INSERT INTO _lock_ids (name, id) SELECT 'seq_nodeannotationlink', nextval('_lock_seq');
CREATE SEQUENCE seq_dimensionorder; INSERT INTO _lock_ids (name, id) SELECT 'seq_dimensionorder', nextval('_lock_seq');
CREATE SEQUENCE seq_binning; INSERT INTO _lock_ids (name, id) SELECT 'seq_binning', nextval('_lock_seq');
CREATE SEQUENCE seq_instrument; INSERT INTO _lock_ids (name, id) SELECT 'seq_instrument', nextval('_lock_seq');
CREATE SEQUENCE seq_namespaceannotationlink; INSERT INTO _lock_ids (name, id) SELECT 'seq_namespaceannotationlink', nextval('_lock_seq');
CREATE SEQUENCE seq_well; INSERT INTO _lock_ids (name, id) SELECT 'seq_well', nextval('_lock_seq');
CREATE SEQUENCE seq_family; INSERT INTO _lock_ids (name, id) SELECT 'seq_family', nextval('_lock_seq');
CREATE SEQUENCE seq_imagingenvironment; INSERT INTO _lock_ids (name, id) SELECT 'seq_imagingenvironment', nextval('_lock_seq');
CREATE SEQUENCE seq_illumination; INSERT INTO _lock_ids (name, id) SELECT 'seq_illumination', nextval('_lock_seq');
CREATE SEQUENCE seq_projectannotationlink; INSERT INTO _lock_ids (name, id) SELECT 'seq_projectannotationlink', nextval('_lock_seq');
CREATE SEQUENCE seq_detectortype; INSERT INTO _lock_ids (name, id) SELECT 'seq_detectortype', nextval('_lock_seq');
CREATE SEQUENCE seq_reagent; INSERT INTO _lock_ids (name, id) SELECT 'seq_reagent', nextval('_lock_seq');
CREATE SEQUENCE seq_pulse; INSERT INTO _lock_ids (name, id) SELECT 'seq_pulse', nextval('_lock_seq');
CREATE SEQUENCE seq_detector; INSERT INTO _lock_ids (name, id) SELECT 'seq_detector', nextval('_lock_seq');
CREATE SEQUENCE seq_otf; INSERT INTO _lock_ids (name, id) SELECT 'seq_otf', nextval('_lock_seq');
CREATE SEQUENCE seq_reagentannotationlink; INSERT INTO _lock_ids (name, id) SELECT 'seq_reagentannotationlink', nextval('_lock_seq');
CREATE SEQUENCE seq_lightsettings; INSERT INTO _lock_ids (name, id) SELECT 'seq_lightsettings', nextval('_lock_seq');
CREATE SEQUENCE seq_originalfile; INSERT INTO _lock_ids (name, id) SELECT 'seq_originalfile', nextval('_lock_seq');
CREATE SEQUENCE seq_lightsource; INSERT INTO _lock_ids (name, id) SELECT 'seq_lightsource', nextval('_lock_seq');
CREATE SEQUENCE seq_annotation; INSERT INTO _lock_ids (name, id) SELECT 'seq_annotation', nextval('_lock_seq');
CREATE SEQUENCE seq_job; INSERT INTO _lock_ids (name, id) SELECT 'seq_job', nextval('_lock_seq');
CREATE SEQUENCE seq_sharemember; INSERT INTO _lock_ids (name, id) SELECT 'seq_sharemember', nextval('_lock_seq');
CREATE SEQUENCE seq_dbpatch; INSERT INTO _lock_ids (name, id) SELECT 'seq_dbpatch', nextval('_lock_seq');
CREATE SEQUENCE seq_filterset; INSERT INTO _lock_ids (name, id) SELECT 'seq_filterset', nextval('_lock_seq');
CREATE SEQUENCE seq_projectdatasetlink; INSERT INTO _lock_ids (name, id) SELECT 'seq_projectdatasetlink', nextval('_lock_seq');
CREATE SEQUENCE seq_experimenterannotationlink; INSERT INTO _lock_ids (name, id) SELECT 'seq_experimenterannotationlink', nextval('_lock_seq');
CREATE SEQUENCE seq_plateannotationlink; INSERT INTO _lock_ids (name, id) SELECT 'seq_plateannotationlink', nextval('_lock_seq');
CREATE SEQUENCE seq_channelbinding; INSERT INTO _lock_ids (name, id) SELECT 'seq_channelbinding', nextval('_lock_seq');
CREATE SEQUENCE seq_microbeammanipulationtype; INSERT INTO _lock_ids (name, id) SELECT 'seq_microbeammanipulationtype', nextval('_lock_seq');
CREATE SEQUENCE seq_medium; INSERT INTO _lock_ids (name, id) SELECT 'seq_medium', nextval('_lock_seq');
CREATE SEQUENCE seq_statsinfo; INSERT INTO _lock_ids (name, id) SELECT 'seq_statsinfo', nextval('_lock_seq');
CREATE SEQUENCE seq_lasermedium; INSERT INTO _lock_ids (name, id) SELECT 'seq_lasermedium', nextval('_lock_seq');
CREATE SEQUENCE seq_pixelstype; INSERT INTO _lock_ids (name, id) SELECT 'seq_pixelstype', nextval('_lock_seq');
CREATE SEQUENCE seq_screen; INSERT INTO _lock_ids (name, id) SELECT 'seq_screen', nextval('_lock_seq');
CREATE SEQUENCE seq_dichroic; INSERT INTO _lock_ids (name, id) SELECT 'seq_dichroic', nextval('_lock_seq');
CREATE SEQUENCE seq_session; INSERT INTO _lock_ids (name, id) SELECT 'seq_session', nextval('_lock_seq');
CREATE SEQUENCE seq_plateacquisition; INSERT INTO _lock_ids (name, id) SELECT 'seq_plateacquisition', nextval('_lock_seq');
CREATE SEQUENCE seq_screenannotationlink; INSERT INTO _lock_ids (name, id) SELECT 'seq_screenannotationlink', nextval('_lock_seq');
CREATE SEQUENCE seq_format; INSERT INTO _lock_ids (name, id) SELECT 'seq_format', nextval('_lock_seq');
CREATE SEQUENCE seq_node; INSERT INTO _lock_ids (name, id) SELECT 'seq_node', nextval('_lock_seq');
CREATE SEQUENCE seq_pixelsannotationlink; INSERT INTO _lock_ids (name, id) SELECT 'seq_pixelsannotationlink', nextval('_lock_seq');
CREATE SEQUENCE seq_objective; INSERT INTO _lock_ids (name, id) SELECT 'seq_objective', nextval('_lock_seq');
CREATE SEQUENCE seq_datasetannotationlink; INSERT INTO _lock_ids (name, id) SELECT 'seq_datasetannotationlink', nextval('_lock_seq');
CREATE SEQUENCE seq_experiment; INSERT INTO _lock_ids (name, id) SELECT 'seq_experiment', nextval('_lock_seq');
CREATE SEQUENCE seq_detectorsettings; INSERT INTO _lock_ids (name, id) SELECT 'seq_detectorsettings', nextval('_lock_seq');
CREATE SEQUENCE seq_correction; INSERT INTO _lock_ids (name, id) SELECT 'seq_correction', nextval('_lock_seq');
CREATE SEQUENCE seq_filter; INSERT INTO _lock_ids (name, id) SELECT 'seq_filter', nextval('_lock_seq');
CREATE SEQUENCE seq_plateacquisitionannotationlink; INSERT INTO _lock_ids (name, id) SELECT 'seq_plateacquisitionannotationlink', nextval('_lock_seq');
CREATE SEQUENCE seq_pixelsoriginalfilemap; INSERT INTO _lock_ids (name, id) SELECT 'seq_pixelsoriginalfilemap', nextval('_lock_seq');
CREATE SEQUENCE seq_logicalchannel; INSERT INTO _lock_ids (name, id) SELECT 'seq_logicalchannel', nextval('_lock_seq');
CREATE SEQUENCE seq_sessionannotationlink; INSERT INTO _lock_ids (name, id) SELECT 'seq_sessionannotationlink', nextval('_lock_seq');
CREATE SEQUENCE seq_screenplatelink; INSERT INTO _lock_ids (name, id) SELECT 'seq_screenplatelink', nextval('_lock_seq');
CREATE SEQUENCE seq_shape; INSERT INTO _lock_ids (name, id) SELECT 'seq_shape', nextval('_lock_seq');
CREATE SEQUENCE seq_experimenter; INSERT INTO _lock_ids (name, id) SELECT 'seq_experimenter', nextval('_lock_seq');
CREATE SEQUENCE seq_acquisitionmode; INSERT INTO _lock_ids (name, id) SELECT 'seq_acquisitionmode', nextval('_lock_seq');
CREATE SEQUENCE seq_event; INSERT INTO _lock_ids (name, id) SELECT 'seq_event', nextval('_lock_seq');
CREATE SEQUENCE seq_jobstatus; INSERT INTO _lock_ids (name, id) SELECT 'seq_jobstatus', nextval('_lock_seq');
CREATE SEQUENCE seq_contrastmethod; INSERT INTO _lock_ids (name, id) SELECT 'seq_contrastmethod', nextval('_lock_seq');


--
-- END #1176/#2508
--


--
-- #1390 : Triggering the addition of an "REINDEX" event on annotation events.
--
CREATE OR REPLACE FUNCTION annotation_update_event_trigger() RETURNS "trigger"
    AS '
    DECLARE
        rec RECORD;
        eid int8;
    BEGIN

        FOR rec IN SELECT id, parent FROM imageannotationlink WHERE child = new.id LOOP
            SELECT into eid ome_nextval(''seq_event'');
            INSERT INTO event (id, permissions, status, time, experimenter, experimentergroup, session, type)
                 SELECT eid, -35, ''TRIGGERED'', now(), 0, 0, 0, 0;
            INSERT INTO eventlog (id, action, permissions, entityid, entitytype, event)
                 SELECT ome_nextval(''seq_eventlog''), ''REINDEX'', -35, rec.parent, ''ome.model.core.Image'', eid;
        END LOOP;

        RETURN new;

    END;'
LANGUAGE plpgsql;

CREATE TRIGGER annotation_trigger
        AFTER UPDATE ON annotation
        FOR EACH ROW
        EXECUTE PROCEDURE annotation_update_event_trigger();


CREATE OR REPLACE FUNCTION annotation_link_event_trigger() RETURNS "trigger"
    AS '
    DECLARE
        eid int8;
    BEGIN

        SELECT into eid ome_nextval(''seq_event'');
        INSERT INTO event (id, permissions, status, time, experimenter, experimentergroup, session, type)
                SELECT eid, -35, ''TRIGGERED'', now(), 0, 0, 0, 0;
        INSERT INTO eventlog (id, action, permissions, entityid, entitytype, event)
                SELECT ome_nextval(''seq_eventlog''), ''REINDEX'', -35, new.parent, ''ome.model.core.Image'', eid;

        RETURN new;

    END;'
LANGUAGE plpgsql;

CREATE TRIGGER image_annotation_link_event_trigger
        AFTER UPDATE ON imageannotationlink
        FOR EACH ROW
        EXECUTE PROCEDURE annotation_link_event_trigger();


--
-- END #1390
--




-- First, we install a unique constraint so that it is only possible
-- to go from versionA/patchA to versionB/patchB once.
--
alter table dbpatch add constraint unique_dbpatch unique (currentVersion, currentPatch, previousVersion, previousPatch);

--
-- Since this is a table that we will be using in DB-specific ways, we're also going
-- to make working with it a bit simpler.
--
alter table dbpatch alter id set default ome_nextval('seq_dbpatch');
alter table dbpatch alter permissions set default -35;
alter table dbpatch alter message set default 'Updating';

--
-- Then, we insert into the patch table the patch (initialization) which we are currently
-- running so that if anything goes wrong, we'll have some record.
--
insert into dbpatch (currentVersion, currentPatch, previousVersion, previousPatch, message)
             values ('OMERO4.2',  0,    'OMERO4.2',   0,             'Initializing');

--
-- Here we will create the root account and the necessary groups
--
insert into experimenter (id,permissions,version,omename,firstname,lastname)
        values (0,0,0,'root','root','root');
insert into experimenter (id,permissions,version,omename,firstname,lastname)
        values (ome_nextval('seq_experimenter'),0,0,'guest','Guest','Account');
insert into node
        (id,permissions,uuid,conn,up,down)
        select 0,-35,'000000000000000000000000000000000000','unknown',now(),now();
insert into session
        (id,permissions,timetoidle,timetolive,started,closed,defaulteventtype,uuid,owner,node)
        select 0,-35,0,0,now(),now(),'BOOTSTRAP',0000, 0,0;
insert into session
        (id,permissions,timetoidle,timetolive,started,closed,defaulteventtype,uuid,owner,node)
        select ome_nextval('seq_session'),-35, 0,0,now(),now(),'PREVIOUSITEMS','1111',0,0;
insert into event (id,permissions,time,status,experimenter,session) values (0,0,now(),'BOOTSTRAP',0,0);

--
-- Default group permissions (ticket:1783)
-- * "system" is private, so that administrators do not share by accident
-- * "user" is public by default since its purpose is to share objects (ticket:1794)
-- * "guest" is private by default so that it doesn't show up on any lists,
--    though nothing should be created there.
--
insert into experimentergroup (id,permissions,version,name)
        values (0,-103,0,'system');
insert into experimentergroup (id,permissions,version,name)
        values (ome_nextval('seq_experimentergroup'),-35,0,'user');
insert into experimentergroup (id,permissions,version,name)
        values (ome_nextval('seq_experimentergroup'),-103,0,'guest');

insert into eventtype (id,permissions,value) values
        (0,-35,'Bootstrap');
insert into groupexperimentermap
        (id,permissions,version, parent, child, child_index,owner)
        values
        (0,-35,0,0,0,0,true);
insert into groupexperimentermap
        (id,permissions,version, parent, child, child_index,owner)
        select ome_nextval('seq_groupexperimentermap'),-35,0,1,0,1,false;
insert into groupexperimentermap
        (id,permissions,version, parent, child, child_index,owner)
        select ome_nextval('seq_groupexperimentermap'),-35,0,2,1,0,false;

update event set type = 0;
update event set experimentergroup = 0;

alter table event alter column type set not null;
alter table event alter column experimentergroup set not null;


insert into filtertype (id,permissions,value)
    select ome_nextval('seq_filtertype'),-35,'LongPass';
insert into filtertype (id,permissions,value)
    select ome_nextval('seq_filtertype'),-35,'ShortPass';
insert into filtertype (id,permissions,value)
    select ome_nextval('seq_filtertype'),-35,'BandPass';
insert into filtertype (id,permissions,value)
    select ome_nextval('seq_filtertype'),-35,'MultiPass';
insert into filtertype (id,permissions,value)
    select ome_nextval('seq_filtertype'),-35,'Dichroic';
insert into filtertype (id,permissions,value)
    select ome_nextval('seq_filtertype'),-35,'NeutralDensity';
insert into filtertype (id,permissions,value)
    select ome_nextval('seq_filtertype'),-35,'Other';
insert into filtertype (id,permissions,value)
    select ome_nextval('seq_filtertype'),-35,'Unknown';
insert into immersion (id,permissions,value)
    select ome_nextval('seq_immersion'),-35,'Oil';
insert into immersion (id,permissions,value)
    select ome_nextval('seq_immersion'),-35,'Water';
insert into immersion (id,permissions,value)
    select ome_nextval('seq_immersion'),-35,'WaterDipping';
insert into immersion (id,permissions,value)
    select ome_nextval('seq_immersion'),-35,'Air';
insert into immersion (id,permissions,value)
    select ome_nextval('seq_immersion'),-35,'Multi';
insert into immersion (id,permissions,value)
    select ome_nextval('seq_immersion'),-35,'Glycerol';
insert into immersion (id,permissions,value)
    select ome_nextval('seq_immersion'),-35,'Other';
insert into immersion (id,permissions,value)
    select ome_nextval('seq_immersion'),-35,'Unknown';
insert into arctype (id,permissions,value)
    select ome_nextval('seq_arctype'),-35,'Hg';
insert into arctype (id,permissions,value)
    select ome_nextval('seq_arctype'),-35,'Xe';
insert into arctype (id,permissions,value)
    select ome_nextval('seq_arctype'),-35,'HgXe';
insert into arctype (id,permissions,value)
    select ome_nextval('seq_arctype'),-35,'Other';
insert into arctype (id,permissions,value)
    select ome_nextval('seq_arctype'),-35,'Unknown';
insert into experimenttype (id,permissions,value)
    select ome_nextval('seq_experimenttype'),-35,'FP';
insert into experimenttype (id,permissions,value)
    select ome_nextval('seq_experimenttype'),-35,'FRET';
insert into experimenttype (id,permissions,value)
    select ome_nextval('seq_experimenttype'),-35,'TimeLapse';
insert into experimenttype (id,permissions,value)
    select ome_nextval('seq_experimenttype'),-35,'FourDPlus';
insert into experimenttype (id,permissions,value)
    select ome_nextval('seq_experimenttype'),-35,'Screen';
insert into experimenttype (id,permissions,value)
    select ome_nextval('seq_experimenttype'),-35,'Immunocytochemistry';
insert into experimenttype (id,permissions,value)
    select ome_nextval('seq_experimenttype'),-35,'Immunofluorescence';
insert into experimenttype (id,permissions,value)
    select ome_nextval('seq_experimenttype'),-35,'FISH';
insert into experimenttype (id,permissions,value)
    select ome_nextval('seq_experimenttype'),-35,'Electrophysiology';
insert into experimenttype (id,permissions,value)
    select ome_nextval('seq_experimenttype'),-35,'IonImaging';
insert into experimenttype (id,permissions,value)
    select ome_nextval('seq_experimenttype'),-35,'Colocalization';
insert into experimenttype (id,permissions,value)
    select ome_nextval('seq_experimenttype'),-35,'PGIDocumentation';
insert into experimenttype (id,permissions,value)
    select ome_nextval('seq_experimenttype'),-35,'FluorescenceLifetime';
insert into experimenttype (id,permissions,value)
    select ome_nextval('seq_experimenttype'),-35,'SpectralImaging';
insert into experimenttype (id,permissions,value)
    select ome_nextval('seq_experimenttype'),-35,'Photobleaching';
insert into experimenttype (id,permissions,value)
    select ome_nextval('seq_experimenttype'),-35,'Other';
insert into experimenttype (id,permissions,value)
    select ome_nextval('seq_experimenttype'),-35,'Unknown';
insert into renderingmodel (id,permissions,value)
    select ome_nextval('seq_renderingmodel'),-35,'rgb';
insert into renderingmodel (id,permissions,value)
    select ome_nextval('seq_renderingmodel'),-35,'greyscale';
insert into eventtype (id,permissions,value)
    select ome_nextval('seq_eventtype'),-35,'Import';
insert into eventtype (id,permissions,value)
    select ome_nextval('seq_eventtype'),-35,'Internal';
insert into eventtype (id,permissions,value)
    select ome_nextval('seq_eventtype'),-35,'Shoola';
insert into eventtype (id,permissions,value)
    select ome_nextval('seq_eventtype'),-35,'User';
insert into eventtype (id,permissions,value)
    select ome_nextval('seq_eventtype'),-35,'Task';
insert into eventtype (id,permissions,value)
    select ome_nextval('seq_eventtype'),-35,'Test';
insert into eventtype (id,permissions,value)
    select ome_nextval('seq_eventtype'),-35,'Processing';
insert into eventtype (id,permissions,value)
    select ome_nextval('seq_eventtype'),-35,'FullText';
insert into eventtype (id,permissions,value)
    select ome_nextval('seq_eventtype'),-35,'Sessions';
insert into microscopetype (id,permissions,value)
    select ome_nextval('seq_microscopetype'),-35,'Upright';
insert into microscopetype (id,permissions,value)
    select ome_nextval('seq_microscopetype'),-35,'Inverted';
insert into microscopetype (id,permissions,value)
    select ome_nextval('seq_microscopetype'),-35,'Dissection';
insert into microscopetype (id,permissions,value)
    select ome_nextval('seq_microscopetype'),-35,'Electrophysiology';
insert into microscopetype (id,permissions,value)
    select ome_nextval('seq_microscopetype'),-35,'Other';
insert into microscopetype (id,permissions,value)
    select ome_nextval('seq_microscopetype'),-35,'Unknown';
insert into filamenttype (id,permissions,value)
    select ome_nextval('seq_filamenttype'),-35,'Incandescent';
insert into filamenttype (id,permissions,value)
    select ome_nextval('seq_filamenttype'),-35,'Halogen';
insert into filamenttype (id,permissions,value)
    select ome_nextval('seq_filamenttype'),-35,'Other';
insert into filamenttype (id,permissions,value)
    select ome_nextval('seq_filamenttype'),-35,'Unknown';
insert into photometricinterpretation (id,permissions,value)
    select ome_nextval('seq_photometricinterpretation'),-35,'RGB';
insert into photometricinterpretation (id,permissions,value)
    select ome_nextval('seq_photometricinterpretation'),-35,'ARGB';
insert into photometricinterpretation (id,permissions,value)
    select ome_nextval('seq_photometricinterpretation'),-35,'CMYK';
insert into photometricinterpretation (id,permissions,value)
    select ome_nextval('seq_photometricinterpretation'),-35,'HSV';
insert into photometricinterpretation (id,permissions,value)
    select ome_nextval('seq_photometricinterpretation'),-35,'Monochrome';
insert into photometricinterpretation (id,permissions,value)
    select ome_nextval('seq_photometricinterpretation'),-35,'ColorMap';
insert into lasertype (id,permissions,value)
    select ome_nextval('seq_lasertype'),-35,'Excimer';
insert into lasertype (id,permissions,value)
    select ome_nextval('seq_lasertype'),-35,'Gas';
insert into lasertype (id,permissions,value)
    select ome_nextval('seq_lasertype'),-35,'MetalVapor';
insert into lasertype (id,permissions,value)
    select ome_nextval('seq_lasertype'),-35,'SolidState';
insert into lasertype (id,permissions,value)
    select ome_nextval('seq_lasertype'),-35,'Dye';
insert into lasertype (id,permissions,value)
    select ome_nextval('seq_lasertype'),-35,'Semiconductor';
insert into lasertype (id,permissions,value)
    select ome_nextval('seq_lasertype'),-35,'FreeElectron';
insert into lasertype (id,permissions,value)
    select ome_nextval('seq_lasertype'),-35,'Other';
insert into lasertype (id,permissions,value)
    select ome_nextval('seq_lasertype'),-35,'Unknown';
insert into dimensionorder (id,permissions,value)
    select ome_nextval('seq_dimensionorder'),-35,'XYZCT';
insert into dimensionorder (id,permissions,value)
    select ome_nextval('seq_dimensionorder'),-35,'XYZTC';
insert into dimensionorder (id,permissions,value)
    select ome_nextval('seq_dimensionorder'),-35,'XYCTZ';
insert into dimensionorder (id,permissions,value)
    select ome_nextval('seq_dimensionorder'),-35,'XYCZT';
insert into dimensionorder (id,permissions,value)
    select ome_nextval('seq_dimensionorder'),-35,'XYTCZ';
insert into dimensionorder (id,permissions,value)
    select ome_nextval('seq_dimensionorder'),-35,'XYTZC';
insert into binning (id,permissions,value)
    select ome_nextval('seq_binning'),-35,'1x1';
insert into binning (id,permissions,value)
    select ome_nextval('seq_binning'),-35,'2x2';
insert into binning (id,permissions,value)
    select ome_nextval('seq_binning'),-35,'4x4';
insert into binning (id,permissions,value)
    select ome_nextval('seq_binning'),-35,'8x8';
insert into family (id,permissions,value)
    select ome_nextval('seq_family'),-35,'linear';
insert into family (id,permissions,value)
    select ome_nextval('seq_family'),-35,'polynomial';
insert into family (id,permissions,value)
    select ome_nextval('seq_family'),-35,'exponential';
insert into family (id,permissions,value)
    select ome_nextval('seq_family'),-35,'logarithmic';
insert into illumination (id,permissions,value)
    select ome_nextval('seq_illumination'),-35,'Transmitted';
insert into illumination (id,permissions,value)
    select ome_nextval('seq_illumination'),-35,'Epifluorescence';
insert into illumination (id,permissions,value)
    select ome_nextval('seq_illumination'),-35,'Oblique';
insert into illumination (id,permissions,value)
    select ome_nextval('seq_illumination'),-35,'NonLinear';
insert into illumination (id,permissions,value)
    select ome_nextval('seq_illumination'),-35,'Other';
insert into illumination (id,permissions,value)
    select ome_nextval('seq_illumination'),-35,'Unknown';
insert into detectortype (id,permissions,value)
    select ome_nextval('seq_detectortype'),-35,'CCD';
insert into detectortype (id,permissions,value)
    select ome_nextval('seq_detectortype'),-35,'IntensifiedCCD';
insert into detectortype (id,permissions,value)
    select ome_nextval('seq_detectortype'),-35,'AnalogVideo';
insert into detectortype (id,permissions,value)
    select ome_nextval('seq_detectortype'),-35,'PMT';
insert into detectortype (id,permissions,value)
    select ome_nextval('seq_detectortype'),-35,'Photodiode';
insert into detectortype (id,permissions,value)
    select ome_nextval('seq_detectortype'),-35,'Spectroscopy';
insert into detectortype (id,permissions,value)
    select ome_nextval('seq_detectortype'),-35,'LifetimeImaging';
insert into detectortype (id,permissions,value)
    select ome_nextval('seq_detectortype'),-35,'CorrelationSpectroscopy';
insert into detectortype (id,permissions,value)
    select ome_nextval('seq_detectortype'),-35,'FTIR';
insert into detectortype (id,permissions,value)
    select ome_nextval('seq_detectortype'),-35,'EM-CCD';
insert into detectortype (id,permissions,value)
    select ome_nextval('seq_detectortype'),-35,'APD';
insert into detectortype (id,permissions,value)
    select ome_nextval('seq_detectortype'),-35,'CMOS';
insert into detectortype (id,permissions,value)
    select ome_nextval('seq_detectortype'),-35,'EBCCD';
insert into detectortype (id,permissions,value)
    select ome_nextval('seq_detectortype'),-35,'Other';
insert into detectortype (id,permissions,value)
    select ome_nextval('seq_detectortype'),-35,'Unknown';
insert into pulse (id,permissions,value)
    select ome_nextval('seq_pulse'),-35,'CW';
insert into pulse (id,permissions,value)
    select ome_nextval('seq_pulse'),-35,'Single';
insert into pulse (id,permissions,value)
    select ome_nextval('seq_pulse'),-35,'QSwitched';
insert into pulse (id,permissions,value)
    select ome_nextval('seq_pulse'),-35,'Repetitive';
insert into pulse (id,permissions,value)
    select ome_nextval('seq_pulse'),-35,'ModeLocked';
insert into pulse (id,permissions,value)
    select ome_nextval('seq_pulse'),-35,'Other';
insert into pulse (id,permissions,value)
    select ome_nextval('seq_pulse'),-35,'Unknown';
insert into microbeammanipulationtype (id,permissions,value)
    select ome_nextval('seq_microbeammanipulationtype'),-35,'FRAP';
insert into microbeammanipulationtype (id,permissions,value)
    select ome_nextval('seq_microbeammanipulationtype'),-35,'Photoablation';
insert into microbeammanipulationtype (id,permissions,value)
    select ome_nextval('seq_microbeammanipulationtype'),-35,'Photoactivation';
insert into microbeammanipulationtype (id,permissions,value)
    select ome_nextval('seq_microbeammanipulationtype'),-35,'Uncaging';
insert into microbeammanipulationtype (id,permissions,value)
    select ome_nextval('seq_microbeammanipulationtype'),-35,'OpticalTrapping';
insert into microbeammanipulationtype (id,permissions,value)
    select ome_nextval('seq_microbeammanipulationtype'),-35,'FLIP';
insert into microbeammanipulationtype (id,permissions,value)
    select ome_nextval('seq_microbeammanipulationtype'),-35,'InverseFRAP';
insert into microbeammanipulationtype (id,permissions,value)
    select ome_nextval('seq_microbeammanipulationtype'),-35,'Other';
insert into microbeammanipulationtype (id,permissions,value)
    select ome_nextval('seq_microbeammanipulationtype'),-35,'Unknown';
insert into medium (id,permissions,value)
    select ome_nextval('seq_medium'),-35,'Air';
insert into medium (id,permissions,value)
    select ome_nextval('seq_medium'),-35,'Oil';
insert into medium (id,permissions,value)
    select ome_nextval('seq_medium'),-35,'Water';
insert into medium (id,permissions,value)
    select ome_nextval('seq_medium'),-35,'Glycerol';
insert into medium (id,permissions,value)
    select ome_nextval('seq_medium'),-35,'Other';
insert into medium (id,permissions,value)
    select ome_nextval('seq_medium'),-35,'Unknown';
insert into lasermedium (id,permissions,value)
    select ome_nextval('seq_lasermedium'),-35,'Rhodamine6G';
insert into lasermedium (id,permissions,value)
    select ome_nextval('seq_lasermedium'),-35,'CoumarinC30';
insert into lasermedium (id,permissions,value)
    select ome_nextval('seq_lasermedium'),-35,'ArFl';
insert into lasermedium (id,permissions,value)
    select ome_nextval('seq_lasermedium'),-35,'ArCl';
insert into lasermedium (id,permissions,value)
    select ome_nextval('seq_lasermedium'),-35,'KrFl';
insert into lasermedium (id,permissions,value)
    select ome_nextval('seq_lasermedium'),-35,'KrCl';
insert into lasermedium (id,permissions,value)
    select ome_nextval('seq_lasermedium'),-35,'XeFl';
insert into lasermedium (id,permissions,value)
    select ome_nextval('seq_lasermedium'),-35,'XeCl';
insert into lasermedium (id,permissions,value)
    select ome_nextval('seq_lasermedium'),-35,'XeBr';
insert into lasermedium (id,permissions,value)
    select ome_nextval('seq_lasermedium'),-35,'GaAs';
insert into lasermedium (id,permissions,value)
    select ome_nextval('seq_lasermedium'),-35,'GaAlAs';
insert into lasermedium (id,permissions,value)
    select ome_nextval('seq_lasermedium'),-35,'EMinus';
insert into lasermedium (id,permissions,value)
    select ome_nextval('seq_lasermedium'),-35,'Cu';
insert into lasermedium (id,permissions,value)
    select ome_nextval('seq_lasermedium'),-35,'Ag';
insert into lasermedium (id,permissions,value)
    select ome_nextval('seq_lasermedium'),-35,'N';
insert into lasermedium (id,permissions,value)
    select ome_nextval('seq_lasermedium'),-35,'Ar';
insert into lasermedium (id,permissions,value)
    select ome_nextval('seq_lasermedium'),-35,'Kr';
insert into lasermedium (id,permissions,value)
    select ome_nextval('seq_lasermedium'),-35,'Xe';
insert into lasermedium (id,permissions,value)
    select ome_nextval('seq_lasermedium'),-35,'HeNe';
insert into lasermedium (id,permissions,value)
    select ome_nextval('seq_lasermedium'),-35,'HeCd';
insert into lasermedium (id,permissions,value)
    select ome_nextval('seq_lasermedium'),-35,'CO';
insert into lasermedium (id,permissions,value)
    select ome_nextval('seq_lasermedium'),-35,'CO2';
insert into lasermedium (id,permissions,value)
    select ome_nextval('seq_lasermedium'),-35,'H2O';
insert into lasermedium (id,permissions,value)
    select ome_nextval('seq_lasermedium'),-35,'HFl';
insert into lasermedium (id,permissions,value)
    select ome_nextval('seq_lasermedium'),-35,'NdGlass';
insert into lasermedium (id,permissions,value)
    select ome_nextval('seq_lasermedium'),-35,'NdYAG';
insert into lasermedium (id,permissions,value)
    select ome_nextval('seq_lasermedium'),-35,'ErGlass';
insert into lasermedium (id,permissions,value)
    select ome_nextval('seq_lasermedium'),-35,'ErYAG';
insert into lasermedium (id,permissions,value)
    select ome_nextval('seq_lasermedium'),-35,'HoYLF';
insert into lasermedium (id,permissions,value)
    select ome_nextval('seq_lasermedium'),-35,'HoYAG';
insert into lasermedium (id,permissions,value)
    select ome_nextval('seq_lasermedium'),-35,'Ruby';
insert into lasermedium (id,permissions,value)
    select ome_nextval('seq_lasermedium'),-35,'TiSapphire';
insert into lasermedium (id,permissions,value)
    select ome_nextval('seq_lasermedium'),-35,'Alexandrite';
insert into lasermedium (id,permissions,value)
    select ome_nextval('seq_lasermedium'),-35,'Other';
insert into lasermedium (id,permissions,value)
    select ome_nextval('seq_lasermedium'),-35,'Unknown';
insert into pixelstype (id,permissions,value)
    select ome_nextval('seq_pixelstype'),-35,'bit';
insert into pixelstype (id,permissions,value)
    select ome_nextval('seq_pixelstype'),-35,'int8';
insert into pixelstype (id,permissions,value)
    select ome_nextval('seq_pixelstype'),-35,'int16';
insert into pixelstype (id,permissions,value)
    select ome_nextval('seq_pixelstype'),-35,'int32';
insert into pixelstype (id,permissions,value)
    select ome_nextval('seq_pixelstype'),-35,'uint8';
insert into pixelstype (id,permissions,value)
    select ome_nextval('seq_pixelstype'),-35,'uint16';
insert into pixelstype (id,permissions,value)
    select ome_nextval('seq_pixelstype'),-35,'uint32';
insert into pixelstype (id,permissions,value)
    select ome_nextval('seq_pixelstype'),-35,'float';
insert into pixelstype (id,permissions,value)
    select ome_nextval('seq_pixelstype'),-35,'double';
insert into pixelstype (id,permissions,value)
    select ome_nextval('seq_pixelstype'),-35,'complex';
insert into pixelstype (id,permissions,value)
    select ome_nextval('seq_pixelstype'),-35,'double-complex';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'PNG';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/PNG';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'JPEG';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/JPEG';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'PGM';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/PGM';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Fits';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/Fits';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'GIF';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/GIF';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'BMP';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/BMP';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Dicom';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/Dicom';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'BioRad';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/BioRad';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'IPLab';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/IPLab';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Deltavision';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/Deltavision';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'MRC';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/MRC';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Gatan';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/Gatan';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Imaris';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/Imaris';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'OpenlabRaw';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/OpenlabRaw';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'OMEXML';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/OMEXML';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'LIF';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/LIF';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'AVI';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/AVI';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'QT';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/QT';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Pict';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/Pict';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'SDT';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/SDT';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'EPS';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/EPS';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Slidebook';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/Slidebook';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Alicona';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/Alicona';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'MNG';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/MNG';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'NRRD';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/NRRD';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Khoros';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/Khoros';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Visitech';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/Visitech';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'LIM';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/LIM';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'PSD';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/PSD';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'InCell';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/InCell';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'ICS';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/ICS';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'PerkinElmer';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/PerkinElmer';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'TCS';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/TCS';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'FV1000';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/FV1000';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'ZeissZVI';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/ZeissZVI';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'IPW';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/IPW';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'LegacyND2';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/LegacyND2';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'ND2';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/ND2';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'PCI';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/PCI';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'ImarisHDF';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/ImarisHDF';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Metamorph';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/Metamorph';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'ZeissLSM';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/ZeissLSM';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'SEQ';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/SEQ';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Gel';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/Gel';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'ImarisTiff';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/ImarisTiff';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Flex';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/Flex';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'SVS';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/SVS';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Leica';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/Leica';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Nikon';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/Nikon';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Fluoview';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/Fluoview';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Prairie';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/Prairie';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Micromanager';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/Micromanager';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'ImprovisionTiff';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/ImprovisionTiff';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'OMETiff';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/OMETiff';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'MetamorphTiff';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/MetamorphTiff';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Tiff';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/Tiff';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Openlab';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/Openlab';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'MIAS';
insert into format (id,permissions,value)
    select ome_nextval('seq_format'),-35,'Companion/MIAS';
insert into correction (id,permissions,value)
    select ome_nextval('seq_correction'),-35,'UV';
insert into correction (id,permissions,value)
    select ome_nextval('seq_correction'),-35,'PlanApo';
insert into correction (id,permissions,value)
    select ome_nextval('seq_correction'),-35,'PlanFluor';
insert into correction (id,permissions,value)
    select ome_nextval('seq_correction'),-35,'SuperFluor';
insert into correction (id,permissions,value)
    select ome_nextval('seq_correction'),-35,'VioletCorrected';
insert into correction (id,permissions,value)
    select ome_nextval('seq_correction'),-35,'Achro';
insert into correction (id,permissions,value)
    select ome_nextval('seq_correction'),-35,'Achromat';
insert into correction (id,permissions,value)
    select ome_nextval('seq_correction'),-35,'Fluor';
insert into correction (id,permissions,value)
    select ome_nextval('seq_correction'),-35,'Fl';
insert into correction (id,permissions,value)
    select ome_nextval('seq_correction'),-35,'Fluar';
insert into correction (id,permissions,value)
    select ome_nextval('seq_correction'),-35,'Neofluar';
insert into correction (id,permissions,value)
    select ome_nextval('seq_correction'),-35,'Fluotar';
insert into correction (id,permissions,value)
    select ome_nextval('seq_correction'),-35,'Apo';
insert into correction (id,permissions,value)
    select ome_nextval('seq_correction'),-35,'Other';
insert into correction (id,permissions,value)
    select ome_nextval('seq_correction'),-35,'Unknown';
insert into acquisitionmode (id,permissions,value)
    select ome_nextval('seq_acquisitionmode'),-35,'WideField';
insert into acquisitionmode (id,permissions,value)
    select ome_nextval('seq_acquisitionmode'),-35,'LaserScanningConfocalMicroscopy';
insert into acquisitionmode (id,permissions,value)
    select ome_nextval('seq_acquisitionmode'),-35,'SpinningDiskConfocal';
insert into acquisitionmode (id,permissions,value)
    select ome_nextval('seq_acquisitionmode'),-35,'SlitScanConfocal';
insert into acquisitionmode (id,permissions,value)
    select ome_nextval('seq_acquisitionmode'),-35,'MultiPhotonMicroscopy';
insert into acquisitionmode (id,permissions,value)
    select ome_nextval('seq_acquisitionmode'),-35,'StructuredIllumination';
insert into acquisitionmode (id,permissions,value)
    select ome_nextval('seq_acquisitionmode'),-35,'SingleMoleculeImaging';
insert into acquisitionmode (id,permissions,value)
    select ome_nextval('seq_acquisitionmode'),-35,'TotalInternalReflection';
insert into acquisitionmode (id,permissions,value)
    select ome_nextval('seq_acquisitionmode'),-35,'FluorescenceLifetime';
insert into acquisitionmode (id,permissions,value)
    select ome_nextval('seq_acquisitionmode'),-35,'SpectralImaging';
insert into acquisitionmode (id,permissions,value)
    select ome_nextval('seq_acquisitionmode'),-35,'FluorescenceCorrelationSpectroscopy';
insert into acquisitionmode (id,permissions,value)
    select ome_nextval('seq_acquisitionmode'),-35,'NearFieldScanningOpticalMicroscopy';
insert into acquisitionmode (id,permissions,value)
    select ome_nextval('seq_acquisitionmode'),-35,'SecondHarmonicGenerationImaging';
insert into acquisitionmode (id,permissions,value)
    select ome_nextval('seq_acquisitionmode'),-35,'PALM';
insert into acquisitionmode (id,permissions,value)
    select ome_nextval('seq_acquisitionmode'),-35,'STORM';
insert into acquisitionmode (id,permissions,value)
    select ome_nextval('seq_acquisitionmode'),-35,'STED';
insert into acquisitionmode (id,permissions,value)
    select ome_nextval('seq_acquisitionmode'),-35,'TIRF';
insert into acquisitionmode (id,permissions,value)
    select ome_nextval('seq_acquisitionmode'),-35,'FSM';
insert into acquisitionmode (id,permissions,value)
    select ome_nextval('seq_acquisitionmode'),-35,'LCM';
insert into acquisitionmode (id,permissions,value)
    select ome_nextval('seq_acquisitionmode'),-35,'Other';
insert into acquisitionmode (id,permissions,value)
    select ome_nextval('seq_acquisitionmode'),-35,'Unknown';
insert into jobstatus (id,permissions,value)
    select ome_nextval('seq_jobstatus'),-35,'Submitted';
insert into jobstatus (id,permissions,value)
    select ome_nextval('seq_jobstatus'),-35,'Resubmitted';
insert into jobstatus (id,permissions,value)
    select ome_nextval('seq_jobstatus'),-35,'Queued';
insert into jobstatus (id,permissions,value)
    select ome_nextval('seq_jobstatus'),-35,'Requeued';
insert into jobstatus (id,permissions,value)
    select ome_nextval('seq_jobstatus'),-35,'Running';
insert into jobstatus (id,permissions,value)
    select ome_nextval('seq_jobstatus'),-35,'Error';
insert into jobstatus (id,permissions,value)
    select ome_nextval('seq_jobstatus'),-35,'Waiting';
insert into jobstatus (id,permissions,value)
    select ome_nextval('seq_jobstatus'),-35,'Finished';
insert into jobstatus (id,permissions,value)
    select ome_nextval('seq_jobstatus'),-35,'Cancelled';
insert into contrastmethod (id,permissions,value)
    select ome_nextval('seq_contrastmethod'),-35,'Brightfield';
insert into contrastmethod (id,permissions,value)
    select ome_nextval('seq_contrastmethod'),-35,'Phase';
insert into contrastmethod (id,permissions,value)
    select ome_nextval('seq_contrastmethod'),-35,'DIC';
insert into contrastmethod (id,permissions,value)
    select ome_nextval('seq_contrastmethod'),-35,'HoffmanModulation';
insert into contrastmethod (id,permissions,value)
    select ome_nextval('seq_contrastmethod'),-35,'ObliqueIllumination';
insert into contrastmethod (id,permissions,value)
    select ome_nextval('seq_contrastmethod'),-35,'PolarizedLight';
insert into contrastmethod (id,permissions,value)
    select ome_nextval('seq_contrastmethod'),-35,'Darkfield';
insert into contrastmethod (id,permissions,value)
    select ome_nextval('seq_contrastmethod'),-35,'Fluorescence';
insert into contrastmethod (id,permissions,value)
    select ome_nextval('seq_contrastmethod'),-35,'Other';
insert into contrastmethod (id,permissions,value)
    select ome_nextval('seq_contrastmethod'),-35,'Unknown';

--
-- Cryptographic functions for specifying UUID
--

create or replace function uuid() returns character(36)
as '
    select substring(x.my_rand from 1 for 8)||''-''||
           substring(x.my_rand from 9 for 4)||''-4''||
           substring(x.my_rand from 13 for 3)||''-''||x.clock_1||
           substring(x.my_rand from 16 for 3)||''-''||
           substring(x.my_rand from 19 for 12)
from
(select md5(now()::text||random()) as my_rand, to_hex(8+(3*random())::int) as clock_1) as x;'
language sql;

--
-- Configuration table including a UUID uniquely identifying this database.
--
create table configuration ( name varchar(255) primary key, value text );
insert into configuration values ('omero.db.uuid',uuid());

--
-- ticket:2201 - creating repository data structures
--
alter  table pixels add column path text;
alter  table pixels add column name text;
alter  table pixels add column repo varchar(36);
alter  table pixels add column params text[2][];
create index pixels_repo_index on pixels (repo);
-- No unique index on (path, repo, name) since it depends on params

alter  table originalfile alter column mimetype set default 'application/octet-stream';
alter  table originalfile add column repo varchar(36);
alter  table originalfile add column params text[2][];
create index originalfile_mime_index on originalfile (mimetype);
create index originalfile_repo_index on originalfile (repo);
create unique index originalfile_repo_path_index on originalfile (repo, path, name) where repo is not null;

--
-- end ticket:2201
--

-- Indices. See #1640, #2573, etc.
create unique index namespace_name on namespace (name);
create unique index well_col_row on well (plate, "column", "row");
create index planeinfo_pixels on planeinfo (pixels);

create table password ( experimenter_id bigint primary key REFERENCES experimenter (id), hash char(24), dn text );
insert into password values (0,'@ROOTPASS@');
insert into password values (1,'');
-- root can now login with omero.rootpass property value
-- and guest can login with any value

-- Here we have finished initializing this database.
update dbpatch set message = 'Database ready.', finished = now()
  where currentVersion = 'OMERO4.2' and
        currentPatch = 0 and
        previousVersion = 'OMERO4.2' and
        previousPatch = 0;

